==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/ButtonBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ButtonBaseType_$type } from "./ButtonBaseType";
import { ButtonBaseTarget_$type } from "./ButtonBaseTarget";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let ButtonBase = /*@__PURE__*/ (() => {
    class ButtonBase extends BaseElement {
        constructor() {
            super(...arguments);
            this.clicked = null;
            this.g = new WCNativeHelper();
            this.j = null;
            this.focus = null;
            this.blur = null;
        }
        clickedChanged() {
            if (this.clicked != null) {
                this.h.q("click", (a) => this.clicked(this, VoidEventArgs.b(a)), false);
            }
            else {
                this.h.t("click");
            }
        }
        get h() {
            return this.g;
        }
        get nativeElement() {
            return this.j;
        }
        set nativeElement(a) {
            this.j = a;
            this.g.n = this.j;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get b() {
            let ret_ = this.h.m("type");
            ret_ = enumGetBox(ButtonBaseType_$type, EnumUtil.getEnumValue(ButtonBaseType_$type, this.h.f(ButtonBaseType_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonBaseType_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(ButtonBaseType_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.h.u("type", value_);
        }
        get n() {
            let ret_ = this.h.m("href");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.h.u("href", value_);
        }
        get m() {
            let ret_ = this.h.m("download");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.h.u("download", value_);
        }
        get a() {
            let ret_ = this.h.m("target");
            ret_ = enumGetBox(ButtonBaseTarget_$type, EnumUtil.getEnumValue(ButtonBaseTarget_$type, this.h.f(ButtonBaseTarget_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonBaseTarget_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(ButtonBaseTarget_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.h.u("target", value_);
        }
        get o() {
            let ret_ = this.h.m("rel");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.h.u("rel", value_);
        }
        get i() {
            let ret_ = this.h.m("disabled");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.h.u("disabled", value_);
        }
        get l() {
            let ret_ = this.h.m("ariaLabel");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.h.u("ariaLabel", value_);
        }
        get c() {
            let ret_ = this.h.m("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.h.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set c(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.h.u("size", value_);
        }
        focusChanged() {
            if (this.focus != null) {
                this.h.q("focus", (a) => this.focus(this, VoidEventArgs.b(a)));
            }
            else {
                this.h.t("focus");
            }
        }
        blurChanged() {
            if (this.blur != null) {
                this.h.q("blur", (a) => this.blur(this, VoidEventArgs.b(a)));
            }
            else {
                this.h.t("blur");
            }
        }
        t(a) {
            this.nativeElement.focus(this.h.h(a));
        }
        q() {
            this.nativeElement.blur();
        }
    }
    ButtonBase.$t = /*@__PURE__*/ markType(ButtonBase, 'ButtonBase', BaseElement.$);
    return ButtonBase;
})();

==> igniteui-react-18.6.1-beta.0.tgz: package/esm2015/lib/ButtonBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ButtonBaseType_$type } from "./ButtonBaseType";
import { ButtonBaseTarget_$type } from "./ButtonBaseTarget";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let ButtonBase = /*@__PURE__*/ (() => {
    class ButtonBase extends BaseElement {
        constructor() {
            super(...arguments);
            this.clicked = null;
            this.g = new WCNativeHelper();
            this.j = null;
            this.focus = null;
            this.blur = null;
        }
        clickedChanged() {
            if (this.clicked != null) {
                this.h.r("click", (a) => this.clicked(this, VoidEventArgs.b(a)), false);
            }
            else {
                this.h.u("click");
            }
        }
        get h() {
            return this.g;
        }
        get nativeElement() {
            return this.j;
        }
        set nativeElement(a) {
            this.j = a;
            this.g.o = this.j;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get b() {
            let ret_ = this.h.n("type");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(ButtonBaseType_$type, EnumUtil.getEnumValue(ButtonBaseType_$type, this.h.f(ButtonBaseType_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonBaseType_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(ButtonBaseType_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.h.v("type", value_);
        }
        get n() {
            let ret_ = this.h.n("href");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.h.v("href", value_);
        }
        get m() {
            let ret_ = this.h.n("download");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.h.v("download", value_);
        }
        get a() {
            let ret_ = this.h.n("target");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(ButtonBaseTarget_$type, EnumUtil.getEnumValue(ButtonBaseTarget_$type, this.h.f(ButtonBaseTarget_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonBaseTarget_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(ButtonBaseTarget_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.h.v("target", value_);
        }
        get o() {
            let ret_ = this.h.n("rel");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.h.v("rel", value_);
        }
        get i() {
            let ret_ = this.h.n("disabled");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.h.v("disabled", value_);
        }
        get k() {
            let ret_ = this.h.n("form");
            return ret_;
        }
        get c() {
            let ret_ = this.h.n("size");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.h.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set c(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.h.v("size", value_);
        }
        focusChanged() {
            if (this.focus != null) {
                this.h.r("focus", (a) => this.focus(this, VoidEventArgs.b(a)));
            }
            else {
                this.h.u("focus");
            }
        }
        blurChanged() {
            if (this.blur != null) {
                this.h.r("blur", (a) => this.blur(this, VoidEventArgs.b(a)));
            }
            else {
                this.h.u("blur");
            }
        }
        u(a) {
            this.nativeElement.focus(this.h.i(a));
        }
        r() {
            this.nativeElement.click();
        }
        q() {
            this.nativeElement.blur();
        }
    }
    ButtonBase.$t = /*@__PURE__*/ markType(ButtonBase, 'ButtonBase', BaseElement.$);
    return ButtonBase;
})();
